@@ -12,7 +12,6 @@
 package org.scilab.forge.scirenderer;
 
 import org.scilab.forge.scirenderer.buffers.BuffersManager;
-import org.scilab.forge.scirenderer.depthtest.DepthTestManager;
 import org.scilab.forge.scirenderer.picking.PickingManager;
 import org.scilab.forge.scirenderer.renderer.RendererManager;
 import org.scilab.forge.scirenderer.texture.TextureManager;
@@ -48,12 +47,6 @@ public interface Canvas {
      */
     BuffersManager getBuffersManager();
 
-    /**
-     * Return the depth test manager of this canvas.
-     * @return the depth test manager of this canvas.
-     */
-    DepthTestManager getDepthTestManager();
-
     /**
      * Return the picking manager.
      * @return the picking manager.
@@ -84,8 +77,9 @@ public interface Canvas {
      */
     Dimension getDimension();
 
-    /**
-     * Ask the canvas to perform drawing.
-     */
+    /** Ask the canvas to perform asynchronous drawing. */
     void redraw();
+
+    /** Wait until a drawing has been performed */
+    void waitImage();
 }
