@@ -135,16 +135,17 @@ public class RulerDrawer {
             windowSubTicksDelta = normalizedProjectedTicksDirection.times(rulerModel.getSubTicksLength());
             windowTicksDelta = normalizedProjectedTicksDirection.times(rulerModel.getTicksLength());
 
+            DecimalFormat format;
             if (rulerModel.isAutoTicks()) {
-                computeAutoGraduation();
+                format = computeAutoGraduation();
             } else {
-                computeUserGraduation();
+                format = computeUserGraduation();
             }
             computeTicksData();
             draw(drawingTools);
             double distRatio = computeTicksDistanceRatio(windowTicksDirection.getNorm());
 
-            rulerDrawingResult = new RulerDrawingResult(ticksValue, subTicksValue, density, distRatio, normalizedProjectedTicksDirection);
+            rulerDrawingResult = new RulerDrawingResult(format, ticksValue, subTicksValue, density, distRatio, normalizedProjectedTicksDirection);
         }
 
         /**
@@ -203,14 +204,15 @@ public class RulerDrawer {
 
         /**
          * Compute the {@link Graduations} used to the ruler drawing in auto-ticks mode..
+         * @return the used decimal format.
          */
-        private void computeAutoGraduation() {
+        private DecimalFormat computeAutoGraduation() {
             /* The maximum distance corresponding to the actually displayed sprites. */
             double maxSpritesDistance = 0.0;
 
             Graduations currentGraduations = rulerModel.getGraduations();
             Graduations ticksGraduation = currentGraduations;
-
+            DecimalFormat format = currentGraduations.getFormat();
             boolean canGetMore = true;
             while (currentGraduations != null) {
                 /* The maximum distance to any of the sprites' farthest sides at a given iteration. */
@@ -219,7 +221,7 @@ public class RulerDrawer {
                 List<PositionedSprite> newSpritesList = new LinkedList<PositionedSprite>();
                 List<Double> ticks = currentGraduations.getNewValues();
                 for (double value : ticks) {
-                    Texture sprite = computeSprite(value, currentGraduations.getFormat());
+                    Texture sprite = computeSprite(value, format);
                     Vector3d windowPosition = canvasProjection.project(rulerModel.getPosition(value));
 
                     Vector3d delta = projectCenterToEdge(sprite, windowTicksDelta);
@@ -246,19 +248,22 @@ public class RulerDrawer {
 
             this.graduations = ticksGraduation;
             this.maximalSpritesDistance = maxSpritesDistance;
+            return format;
         }
 
         /**
          * Compute the {@link Graduations} used to the ruler drawing in auto-ticks mode..
+         * @return the used decimal format.
          */
-        private void computeUserGraduation() {
+        private DecimalFormat computeUserGraduation() {
             /* The maximum distance corresponding to the actually displayed sprites. */
             double maxSpritesDistance = 0.0;
             Graduations currentGraduations = rulerModel.getGraduations();
 
             List<Double> ticks = currentGraduations.getNewValues();
+            DecimalFormat format = currentGraduations.getFormat();
             for (double value : ticks) {
-                Texture sprite = computeSprite(value, currentGraduations.getFormat());
+                Texture sprite = computeSprite(value, format);
                 if (sprite != null) {
                     Vector3d windowPosition = canvasProjection.project(rulerModel.getPosition(value));
 
@@ -272,6 +277,7 @@ public class RulerDrawer {
 
             this.graduations = currentGraduations;
             this.maximalSpritesDistance = maxSpritesDistance;
+            return format;
         }
 
         /**
