@@ -15,7 +15,7 @@ package org.scilab.forge.scirenderer.tranformations;
  * @author Pierre Lando
  */
 public class Vector4d {
-    private final double data[];
+    private final double[] data;
 
 
     public Vector4d(double x, double y, double z, double w) {
@@ -25,4 +25,8 @@ public class Vector4d {
     public double[] getData() {
         return data.clone();
     }
+
+    public String toString() {
+        return "[" + data[0] + ", " + data[1] + ", " + data[2] + ", " + data[3] + "]";
+    }
 }
